{% extends "tabbed_admin/change_form.html" %}
{% load i18n admin_urls static admin_modify admin_utils %}
{% block object-tools %}
{% if change and not is_popup %}
  <ul class="object-tools">
    {% if has_sort_elements %}
    <li>
        <a href="{{ request.path|get_child_sortable_list }}" class="viewsitelink">Visual Sort Elements</a>
    </li>
    {% endif %}
    {% block object-tools-items %}
    {% change_form_object_tools %}
    {% endblock %}
  </ul>
{% endif %}
{% endblock %}
